@@ -33,9 +33,15 @@
 #include <QStatusBar>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
+
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/NotificationPopup>
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/NotificationPopup>
 #include <KUserFeedback/Provider>
 #endif
+#endif
 
 KOrganizer::KOrganizer()
     : KParts::MainWindow()
